<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="fi">
<context>
    <name>DAboutDialog</name>
    <message>
        <location filename="../widgets/dapplication.cpp" line="1405"/>
        <source>%1 is released under %2</source>
        <translation>%1 on julkaistu %2 -lisenssin alla</translation>
    </message>
</context>
<context>
    <name>DCrumbEdit</name>
    <message>
        <location filename="../widgets/dcrumbedit.cpp" line="869"/>
        <source>Black</source>
        <translation>Musta</translation>
    </message>
    <message>
        <location filename="../widgets/dcrumbedit.cpp" line="872"/>
        <source>White</source>
        <translation>Valkoinen</translation>
    </message>
    <message>
        <location filename="../widgets/dcrumbedit.cpp" line="875"/>
        <source>Dark Gray</source>
        <translation>Tummanharmaa</translation>
    </message>
    <message>
        <location filename="../widgets/dcrumbedit.cpp" line="878"/>
        <source>Gray</source>
        <translation>Harmaa</translation>
    </message>
    <message>
        <location filename="../widgets/dcrumbedit.cpp" line="881"/>
        <source>Light Gray</source>
        <translation>Vaaleanharmaa</translation>
    </message>
    <message>
        <location filename="../widgets/dcrumbedit.cpp" line="884"/>
        <source>Red</source>
        <translation>Punainen</translation>
    </message>
    <message>
        <location filename="../widgets/dcrumbedit.cpp" line="887"/>
        <source>Green</source>
        <translation>Vihreä</translation>
    </message>
    <message>
        <location filename="../widgets/dcrumbedit.cpp" line="890"/>
        <source>Blue</source>
        <translation>Sininen</translation>
    </message>
    <message>
        <location filename="../widgets/dcrumbedit.cpp" line="893"/>
        <source>Cyan</source>
        <translation>Syaani</translation>
    </message>
    <message>
        <location filename="../widgets/dcrumbedit.cpp" line="896"/>
        <source>Magenta</source>
        <translation>Purppura</translation>
    </message>
    <message>
        <location filename="../widgets/dcrumbedit.cpp" line="899"/>
        <source>Yellow</source>
        <translation>Keltainen</translation>
    </message>
    <message>
        <location filename="../widgets/dcrumbedit.cpp" line="902"/>
        <source>Dark Red</source>
        <translation>Tummanpunainen</translation>
    </message>
    <message>
        <location filename="../widgets/dcrumbedit.cpp" line="905"/>
        <source>Dark Green</source>
        <translation>Tummanvihreä</translation>
    </message>
    <message>
        <location filename="../widgets/dcrumbedit.cpp" line="908"/>
        <source>Dark Blue</source>
        <translation>Tummansininen</translation>
    </message>
    <message>
        <location filename="../widgets/dcrumbedit.cpp" line="911"/>
        <source>Dark Cyan</source>
        <translation>Tumma syaani</translation>
    </message>
    <message>
        <location filename="../widgets/dcrumbedit.cpp" line="914"/>
        <source>Dark Magenta</source>
        <translation>Tumma purppura</translation>
    </message>
    <message>
        <location filename="../widgets/dcrumbedit.cpp" line="917"/>
        <source>Dark Yellow</source>
        <translation>Tummankeltainen</translation>
    </message>
</context>
<context>
    <name>DInputDialog</name>
    <message>
        <location filename="../widgets/dinputdialog.cpp" line="29"/>
        <source>Cancel</source>
        <translation>Peruuta</translation>
    </message>
    <message>
        <location filename="../widgets/dinputdialog.cpp" line="30"/>
        <source>Confirm</source>
        <translation>Vahvista</translation>
    </message>
</context>
<context>
    <name>DKeySequenceEdit</name>
    <message>
        <location filename="../widgets/dkeysequenceedit.cpp" line="97"/>
        <source>Enter a new shortcut</source>
        <translation>Tee pikakuvake</translation>
    </message>
</context>
<context>
    <name>DLineEdit</name>
    <message>
        <location filename="../widgets/dlineedit.cpp" line="593"/>
        <source>Stop reading</source>
        <translation>Lopeta lukeminen</translation>
    </message>
    <message>
        <location filename="../widgets/dlineedit.cpp" line="595"/>
        <source>Text to Speech</source>
        <translation>Teksti puheeksi</translation>
    </message>
    <message>
        <location filename="../widgets/dlineedit.cpp" line="618"/>
        <source>Translate</source>
        <translation>Käännös</translation>
    </message>
    <message>
        <location filename="../widgets/dlineedit.cpp" line="640"/>
        <source>Speech To Text</source>
        <translation>Puhe tekstiksi</translation>
    </message>
</context>
<context>
    <name>DPrintPreviewDialogPrivate</name>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="278"/>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="1268"/>
        <source>Advanced</source>
        <translation>Lisäasetukset</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="301"/>
        <source>Cancel</source>
        <comment>button</comment>
        <translation>Peruuta</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="302"/>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="1647"/>
        <source>Print</source>
        <comment>button</comment>
        <translation>Tulosta</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="318"/>
        <source>Basic</source>
        <translation>Oletus</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="334"/>
        <source>Printer</source>
        <translation>Tulostin</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="350"/>
        <source>Copies</source>
        <translation>Kopiot</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="372"/>
        <source>Page range</source>
        <translation>Sivualue</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="375"/>
        <source>All</source>
        <translation>Kaikki</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="376"/>
        <source>Current page</source>
        <translation>Nykyinen sivu</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="377"/>
        <source>Select pages</source>
        <translation>Valitse sivut</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="397"/>
        <source>Orientation</source>
        <translation>Suunta</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="422"/>
        <source>Portrait</source>
        <translation>Pysty</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="432"/>
        <source>Landscape</source>
        <translation>Vaaka</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="460"/>
        <source>Pages</source>
        <translation>Sivut</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="472"/>
        <source>Color mode</source>
        <translation>Väritila</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="475"/>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="1583"/>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="1663"/>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="1679"/>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="1694"/>
        <source>Color</source>
        <translation>Väri</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="475"/>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="1670"/>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="1682"/>
        <source>Grayscale</source>
        <translation>Harmaasävy</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="487"/>
        <source>Margins</source>
        <translation>Marginaalit</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="491"/>
        <source>Narrow (mm)</source>
        <translation>Kapea (mm)</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="491"/>
        <source>Normal (mm)</source>
        <translation>Normaali (mm)</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="491"/>
        <source>Moderate (mm)</source>
        <translation>Kohtalainen (mm)</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="491"/>
        <source>Customize (mm)</source>
        <translation>Mukauta (mm)</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="500"/>
        <source>Top</source>
        <translation>Ylös</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="503"/>
        <source>Left</source>
        <translation>Vasen</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="506"/>
        <source>Bottom</source>
        <translation>Alas</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="509"/>
        <source>Right</source>
        <translation>Oikea</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="556"/>
        <source>Scaling</source>
        <translation>Skaalaus</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="573"/>
        <source>Actual size</source>
        <translation>Todellinen koko</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="582"/>
        <source>Scale</source>
        <translation>Skaalaa</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="613"/>
        <source>Paper</source>
        <translation>Paperi</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="626"/>
        <source>Paper size</source>
        <translation>Paperin koko</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="641"/>
        <source>Print Layout</source>
        <translation>Tulosteen asettelu</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="655"/>
        <source>Duplex</source>
        <translation>Kääntöyksikkö</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="668"/>
        <source>N-up printing</source>
        <translation>Sivuja sivulle</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="671"/>
        <source>2 pages/sheet, 1×2</source>
        <translation>2 sivua/arkki, 1×2</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="671"/>
        <source>4 pages/sheet, 2×2</source>
        <translation>4 sivua/arkki, 2×2</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="671"/>
        <source>6 pages/sheet, 2×3</source>
        <translation>6 sivua/arkki, 2×3</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="671"/>
        <source>9 pages/sheet, 3×3</source>
        <translation>9 sivua/arkki, 3×3</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="671"/>
        <source>16 pages/sheet, 4×4</source>
        <translation>16 sivua/arkki, 4×4</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="683"/>
        <source>Layout direction</source>
        <translation>Asettelun suunta</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="727"/>
        <source>Page Order</source>
        <translation>Sivujärjestys</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="740"/>
        <source>Collate pages</source>
        <translation>Lajittele sivut</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="746"/>
        <source>Print pages in order</source>
        <translation>Sivujen tulostusjärjestys</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="750"/>
        <source>Front to back</source>
        <translation>Edestä taakse</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="750"/>
        <source>Back to front</source>
        <translation>Takaa eteen</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="774"/>
        <source>Watermark</source>
        <translation>Vesileima</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="788"/>
        <source>Add watermark</source>
        <translation>Lisää vesileima</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="834"/>
        <source>Text watermark</source>
        <translation>Vesileiman teksti</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="838"/>
        <source>Confidential</source>
        <translation>Salassapito</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="838"/>
        <source>Draft</source>
        <translation>Vedos</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="838"/>
        <source>Sample</source>
        <translation>Näyte</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="838"/>
        <source>Custom</source>
        <translation>Mukautettu</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="847"/>
        <source>Input your text</source>
        <translation>Syötä teksti</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="872"/>
        <source>Picture watermark</source>
        <translation>Vesileima kuvana</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="896"/>
        <source>Layout</source>
        <translation>Asettelu</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="899"/>
        <source>Tile</source>
        <translation>Ruutu</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="899"/>
        <source>Center</source>
        <translation>Keskitetty</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="912"/>
        <source>Angle</source>
        <translation>Kulma</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="931"/>
        <source>Size</source>
        <translation>Koko</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="955"/>
        <source>Transparency</source>
        <translation>Läpikuultava</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="1013"/>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="2283"/>
        <source>Print to PDF</source>
        <translation>Tulosta PDF</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="1014"/>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="2282"/>
        <source>Save as Image</source>
        <translation>Tallenna kuvana</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="1264"/>
        <source>Collapse</source>
        <translation>Taita</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="1359"/>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="1368"/>
        <source>Flip on short edge</source>
        <translation>Käännä lyhyellä reunalla</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="1298"/>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="1363"/>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="1367"/>
        <source>Flip on long edge</source>
        <translation>Käännä pitkällä reunalla</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="1461"/>
        <source>Input page numbers please</source>
        <translation>Syötä sivunumerot</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="1464"/>
        <source>Maximum page number reached</source>
        <translation>Sivunumeron enimmäismäärä saavutettu</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="1467"/>
        <source>Input English comma please</source>
        <translation>Anna englantilainen pilkku</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="1470"/>
        <source>Input page numbers like this: 1,3,5-7,11-15,18,21</source>
        <translation>Syötä sivunumerot näin: 1,3,5-7,11-15,18,21</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="1700"/>
        <source>Save</source>
        <comment>button</comment>
        <translation>Tallenna</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="2312"/>
        <source>*.pdf</source>
        <translation>*.pdf</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="1770"/>
        <source>For example, 1,3,5-7,11-15,18,21</source>
        <translation>Esimerkki, 1,3,5-7,11-15,18,21</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="2312"/>
        <source>Save as PDF</source>
        <translation>Tallenna PDF</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="2351"/>
        <source>Save as image</source>
        <translation>Tallenna kuvana</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="2353"/>
        <source>Images</source>
        <translation>Kuvat</translation>
    </message>
</context>
<context>
    <name>DPrintPreviewWidget</name>
    <message>
        <location filename="../widgets/dprintpreviewwidget.cpp" line="1590"/>
        <location filename="../widgets/dprintpreviewwidget.cpp" line="1593"/>
        <source>Confidential</source>
        <translation>Salassapito</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewwidget.cpp" line="1608"/>
        <location filename="../widgets/dprintpreviewwidget.cpp" line="1611"/>
        <source>Draft</source>
        <translation>Vedos</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewwidget.cpp" line="1626"/>
        <location filename="../widgets/dprintpreviewwidget.cpp" line="1629"/>
        <source>Sample</source>
        <translation>Näyte</translation>
    </message>
</context>
<context>
    <name>DSearchEdit</name>
    <message>
        <location filename="../widgets/dsearchedit.cpp" line="286"/>
        <source>Search</source>
        <translation>Etsi</translation>
    </message>
</context>
<context>
    <name>DSettingsDialog</name>
    <message>
        <location filename="../widgets/dsettingswidgetfactory.cpp" line="65"/>
        <source>Cancel</source>
        <translation>Peruuta</translation>
    </message>
    <message>
        <location filename="../widgets/dsettingswidgetfactory.cpp" line="66"/>
        <source>Replace</source>
        <translation>Korvaa</translation>
    </message>
    <message>
        <location filename="../widgets/dsettingswidgetfactory.cpp" line="68"/>
        <source>This shortcut conflicts with %1, click on Add to make this shortcut effective immediately</source>
        <translation>Tämä pikakuvake on ristiriidassa %1 kanssa, napsauta Lisää, jotta pikakuvake tulee voimaan heti</translation>
    </message>
</context>
<context>
    <name>DShortcutEdit</name>
    <message>
        <location filename="../widgets/dshortcutedit.cpp" line="18"/>
        <source>Please input a new shortcut</source>
        <translation>Uusi pikakuvake</translation>
    </message>
    <message>
        <location filename="../widgets/dshortcutedit.cpp" line="89"/>
        <source>None</source>
        <translation>Tyhjä</translation>
    </message>
</context>
<context>
    <name>DTextEdit</name>
    <message>
        <location filename="../widgets/dtextedit.cpp" line="202"/>
        <source>Stop reading</source>
        <translation>Lopeta lukeminen</translation>
    </message>
    <message>
        <location filename="../widgets/dtextedit.cpp" line="204"/>
        <source>Text to Speech</source>
        <translation>Teksti puheeksi</translation>
    </message>
    <message>
        <location filename="../widgets/dtextedit.cpp" line="227"/>
        <source>Translate</source>
        <translation>Käännös</translation>
    </message>
    <message>
        <location filename="../widgets/dtextedit.cpp" line="249"/>
        <source>Speech To Text</source>
        <translation>Puhe tekstiksi</translation>
    </message>
</context>
<context>
    <name>DToolbarEditPanel</name>
    <message>
        <location filename="../widgets/private/dtitlebareditpanel.cpp" line="884"/>
        <source>Default toolset</source>
        <translation>Oletus työkalut</translation>
    </message>
    <message>
        <location filename="../widgets/private/dtitlebareditpanel.cpp" line="915"/>
        <source>Drag your favorite items into the toolbar</source>
        <translation>Vedä sinun suosikit työkalupalkkiin</translation>
    </message>
    <message>
        <location filename="../widgets/private/dtitlebareditpanel.cpp" line="916"/>
        <source>Drag below items into the toolbar to restore defaults</source>
        <translation>Palauta oletukset vetämällä alla olevat työkalupalkkiin</translation>
    </message>
    <message>
        <location filename="../widgets/private/dtitlebareditpanel.cpp" line="921"/>
        <source>Confirm</source>
        <translation>Vahvista</translation>
    </message>
</context>
<context>
    <name>PickColorWidget</name>
    <message>
        <location filename="../widgets/dprintpickcolorwidget.cpp" line="94"/>
        <source>Color</source>
        <translation>Väri</translation>
    </message>
</context>
<context>
    <name>QLineEdit</name>
    <message>
        <location filename="../widgets/dlineedit.cpp" line="526"/>
        <source>&amp;Copy</source>
        <translation>&amp;Kopioi</translation>
    </message>
    <message>
        <location filename="../widgets/dlineedit.cpp" line="529"/>
        <source>Cu&amp;t</source>
        <translation>&amp;Leikkaa</translation>
    </message>
    <message>
        <location filename="../widgets/dlineedit.cpp" line="534"/>
        <source>Select All</source>
        <translation>Valitse kaikki</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../widgets/dsimplelistview.cpp" line="1347"/>
        <source>No search result</source>
        <translation>Ei hakutuloksia</translation>
    </message>
    <message>
        <location filename="../widgets/private/settings/content.cpp" line="330"/>
        <source>Restore Defaults</source>
        <translation>Palauta oletukset</translation>
    </message>
    <message>
        <location filename="../widgets/daboutdialog.cpp" line="109"/>
        <source>Version</source>
        <translation>Versio</translation>
    </message>
    <message>
        <location filename="../widgets/daboutdialog.cpp" line="111"/>
        <source>Features</source>
        <translation>Ominaisuuksia</translation>
    </message>
    <message>
        <location filename="../widgets/daboutdialog.cpp" line="123"/>
        <source>Homepage</source>
        <translation>Kotisivu</translation>
    </message>
    <message>
        <location filename="../widgets/daboutdialog.cpp" line="125"/>
        <source>Description</source>
        <translation>Kuvaus</translation>
    </message>
    <message>
        <location filename="../widgets/daboutdialog.cpp" line="127"/>
        <source>Acknowledgements</source>
        <translation>Kiitokset</translation>
    </message>
    <message>
        <location filename="../widgets/daboutdialog.cpp" line="129"/>
        <location filename="../widgets/daboutdialog.cpp" line="138"/>
        <source>Sincerely appreciate the open-source software used.</source>
        <translation>Arvostamme avoimen lähdekoodin ohjelmistoa.</translation>
    </message>
    <message>
        <location filename="../widgets/daboutdialog.cpp" line="140"/>
        <source>open-source software</source>
        <translation>avoimen lähdekoodin ohjelmisto</translation>
    </message>
    <message>
        <location filename="../widgets/dfeaturedisplaydialog.cpp" line="151"/>
        <source>Continue</source>
        <translation>Jatka</translation>
    </message>
    <message>
        <location filename="../widgets/dfeaturedisplaydialog.cpp" line="175"/>
        <source>Learn More</source>
        <translation>Lisätietoja</translation>
    </message>
    <message>
        <location filename="../widgets/dlicensedialog.cpp" line="141"/>
        <source>Open-Source Software</source>
        <translation>Avoimen lähdekoodin ohjelmisto</translation>
    </message>
</context>
<context>
    <name>QWidgetTextControl</name>
    <message>
        <location filename="../widgets/dtextedit.cpp" line="194"/>
        <source>Select All</source>
        <translation>Valitse kaikki</translation>
    </message>
</context>
<context>
    <name>ShortcutEdit</name>
    <message>
        <location filename="../widgets/private/settings/shortcutedit.cpp" line="104"/>
        <source>Please enter a new shortcut</source>
        <translation>Anna uusi pikakuvake</translation>
    </message>
</context>
<context>
    <name>TitleBarMenu</name>
    <message>
        <location filename="../widgets/dtitlebar.cpp" line="634"/>
        <source>Theme</source>
        <translation>Teema</translation>
    </message>
    <message>
        <location filename="../widgets/dtitlebar.cpp" line="636"/>
        <source>Light Theme</source>
        <translation>Vaalea</translation>
    </message>
    <message>
        <location filename="../widgets/dtitlebar.cpp" line="637"/>
        <source>Dark Theme</source>
        <translation>Tumma</translation>
    </message>
    <message>
        <location filename="../widgets/dtitlebar.cpp" line="638"/>
        <source>System Theme</source>
        <translation>Järjestelmän</translation>
    </message>
    <message>
        <location filename="../widgets/dtitlebar.cpp" line="668"/>
        <source>Help</source>
        <translation>Apua</translation>
    </message>
    <message>
        <location filename="../widgets/dtitlebar.cpp" line="676"/>
        <source>Feedback</source>
        <translation>Palaute</translation>
    </message>
    <message>
        <location filename="../widgets/dtitlebar.cpp" line="683"/>
        <source>Custom toolbar</source>
        <translation>Mukautettu työkalupalkki</translation>
    </message>
    <message>
        <location filename="../widgets/dtitlebar.cpp" line="691"/>
        <source>About</source>
        <translation>Tietoja</translation>
    </message>
    <message>
        <location filename="../widgets/dtitlebar.cpp" line="698"/>
        <source>Exit</source>
        <translation>Poistu</translation>
    </message>
</context>
</TS>